==> react-rating-icons-1.5.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';

var RatingIcons =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(RatingIcons, _Component);

  function RatingIcons() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      ratingFilledWidth: 0
    };
    return _this;
  }

  var _proto = RatingIcons.prototype;

  _proto.calculateWidthByRating = function calculateWidthByRating() {
    var _this$props = this.props,
        maxValue = _this$props.maxValue,
        iconSize = _this$props.iconSize,
        rating = _this$props.rating,
        spacingBetween = _this$props.spacingBetween;
    return maxValue * (iconSize + spacingBetween) / maxValue * rating;
  };

  _proto.getIcon = function getIcon(Icon, index) {
    return React.createElement("div", {
      key: index,
      className: "sui-RatingIcons-iconContainer",
      style: {
        minWidth: this.props.iconSize,
        marginLeft: this.props.spacingBetween
      }
    }, React.createElement(Icon, null));
  };

  _proto.buildRating = function buildRating(maxValue, icon) {
    var iconsArray = [];

    for (var i = 0; i < maxValue; i++) {
      iconsArray.push(this.getIcon(icon, i));
    }

    return iconsArray;
  };

  _proto.componentDidMount = function componentDidMount() {
    var currentRatingFilledWidth = this.calculateWidthByRating(this.props.rating, this.props.maxValue, this.ratingEle);

    if (currentRatingFilledWidth !== this.state.ratingFilledWidth) {
      this.setState({
        ratingFilledWidth: currentRatingFilledWidth
      });
    }
  };

  _proto.render = function render() {
    var _this$props2 = this.props,
        maxValue = _this$props2.maxValue,
        icon = _this$props2.icon,
        fillColor = _this$props2.fillColor,
        emptyColor = _this$props2.emptyColor;
    var ratingIcons = this.buildRating(maxValue, icon);
    return React.createElement("div", {
      className: "sui-RatingIcons"
    }, React.createElement("div", {
      className: "sui-RatingIcons-empty",
      style: {
        fill: emptyColor
      }
    }, ratingIcons), React.createElement("div", {
      className: "sui-RatingIcons-filled",
      style: {
        width: this.state.ratingFilledWidth,
        fill: fillColor
      }
    }, ratingIcons));
  };

  return RatingIcons;
}(Component);

RatingIcons.displayName = 'RatingIcons';
RatingIcons.defaultProps = {
  spacingBetween: 0
};
export default RatingIcons;

==> react-rating-icons-1.6.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { Component } from 'react';

var RatingIcons = /*#__PURE__*/function (_Component) {
  _inheritsLoose(RatingIcons, _Component);

  function RatingIcons() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      ratingFilledWidth: 0
    };
    return _this;
  }

  var _proto = RatingIcons.prototype;

  _proto.calculateWidthByRating = function calculateWidthByRating() {
    var _this$props = this.props,
        maxValue = _this$props.maxValue,
        iconSize = _this$props.iconSize,
        rating = _this$props.rating,
        spacingBetween = _this$props.spacingBetween;
    return maxValue * (iconSize + spacingBetween) / maxValue * rating;
  };

  _proto.getIcon = function getIcon(Icon, index) {
    return /*#__PURE__*/_jsx("div", {
      className: "sui-RatingIcons-iconContainer",
      style: {
        minWidth: this.props.iconSize,
        marginLeft: this.props.spacingBetween
      },
      children: /*#__PURE__*/_jsx(Icon, {})
    }, index);
  };

  _proto.buildRating = function buildRating(maxValue, icon) {
    var iconsArray = [];

    for (var i = 0; i < maxValue; i++) {
      iconsArray.push(this.getIcon(icon, i));
    }

    return iconsArray;
  };

  _proto.componentDidMount = function componentDidMount() {
    var currentRatingFilledWidth = this.calculateWidthByRating(this.props.rating, this.props.maxValue, this.ratingEle);

    if (currentRatingFilledWidth !== this.state.ratingFilledWidth) {
      this.setState({
        ratingFilledWidth: currentRatingFilledWidth
      });
    }
  };

  _proto.render = function render() {
    var _this$props2 = this.props,
        maxValue = _this$props2.maxValue,
        icon = _this$props2.icon,
        fillColor = _this$props2.fillColor,
        emptyColor = _this$props2.emptyColor;
    var ratingIcons = this.buildRating(maxValue, icon);
    return /*#__PURE__*/_jsxs("div", {
      className: "sui-RatingIcons",
      children: [/*#__PURE__*/_jsx("div", {
        className: "sui-RatingIcons-empty",
        style: {
          fill: emptyColor
        },
        children: ratingIcons
      }), /*#__PURE__*/_jsx("div", {
        className: "sui-RatingIcons-filled",
        style: {
          width: this.state.ratingFilledWidth,
          fill: fillColor
        },
        children: ratingIcons
      })]
    });
  };

  return RatingIcons;
}(Component);

RatingIcons.displayName = 'RatingIcons';
RatingIcons.defaultProps = {
  spacingBetween: 0
};
export default RatingIcons;
